# shw
shw is a ssh shortcut CLI python package, saving your ssh configure command as a key name, saving your time.

## INSTALL

use pip.

```
pip install shw
```

## USE

1. edit your ~/.shw.json file, make sure the format is correct.
2. type `shw -n ssh_config_name` to simply use.


Feature work will cover more feature.
